@@ -1,7 +1,6 @@
 import numpy as np
 import codecs, json
 import copy
-import random
 
 def softmax(x):
     e_x = np.exp(x - np.max(x))
@@ -26,7 +25,7 @@ class Population:
     def __init__(self, size, hl_count, layer_node_counts):
         self.birds = []
         for i in range(size):
-            self.birds.append(Bird(hl_count, layer_node_counts))
+            self.birds.append(Bird(hl_count, layer_node_counts)) 
 
     def breed(self):
         odds = []
@@ -36,10 +35,8 @@ class Population:
         for i in self.birds:
             odds.append(i.fitness / (total_fit - i.fitness))
         odds /= np.sum(odds)
-        print([max(odds), min(odds)])
         
         next_gen = []
-        next_gen = sorted(self.birds, key=lambda x: x.fitness)[-int(np.floor(len(self.birds) * .2)):]
         while len(next_gen) < len(self.birds):
             p1 = np.random.choice(self.birds, 1, p=odds)[0]
             p2 = np.random.choice(self.birds, 1, p=odds)[0]
@@ -56,20 +53,23 @@ class Population:
 
     def mutate(self, mutate_r8, radius_ratio, reinit=0.01, immune=1):
         police = []
+        complete = 0
         for i in range(immune):
             police.append(sorted(self.birds, key=lambda x: x.fitness)[-i])
+            complete += 1
         for bird in self.birds:
+            complete += 1
             if np.random.uniform() < .98:
                 for matrix in range(len(bird.matrices)):
                     for row in range(len(bird.matrices[matrix])):
                         for col in range(len(bird.matrices[matrix][0])):
                             if np.random.uniform() < mutate_r8:
                                 bird.matrices[matrix][row][col] += np.random.normal(0, radius_ratio / np.sqrt(len(bird.matrices[matrix][0])), 1)[0]
-        random.shuffle(self.birds)
+        np.random.shuffle(self.birds)
         for i in range(immune):
             del self.birds[i]
             self.birds.append(police[i])
-        random.shuffle(self.birds)
+        np.random.shuffle(self.birds)
 
 class Bird:
     def __init__(self, hl_count, layer_node_counts, mat = []):
